@@ -15,14 +15,14 @@ import (
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 )
 
 // Reason messages used in status conditions.
 const (
-	ReasonEmpty             = ""
+	ReasonAsExpected        = "AsExpected"
 	ReasonMissingDependency = "MissingDependency"
 	ReasonSyncing           = "SyncingResources"
 	ReasonCheckAutoscaler   = "UnableToCheckAutoscalers"
@@ -344,7 +344,7 @@ func (r *StatusReporter) ReportStatus() (bool, error) {
 	}
 
 	msg := fmt.Sprintf("at version %s", r.config.ReleaseVersion)
-	if err := r.available(ReasonEmpty, msg); err != nil {
+	if err := r.available(ReasonAsExpected, msg); err != nil {
 		return false, err
 	}
 
